@@ -117,7 +117,7 @@ class WecomUserExtraInfo(mongoengine.DynamicDocument, MultiDatabaseMixin):
 class IllegalMeta(mongoengine.EmbeddedDocument):
     illegal_type = mongoengine.StringField(verbose_name="违规类型")
     illegal_level = mongoengine.IntField(verbose_name="违规等级")
-    illegal_words = mongoengine.ListField(mongoengine.StringField())
+    illegal_words = mongoengine.ListField(mongoengine.StringField(), verbose_name="违规词")
 
     def __str__(self):
         return f"{self.illegal_type}-{self.illegal_type}-{self.illegal_words}"
@@ -128,8 +128,15 @@ class MessageCheckResult(mongoengine.DynamicDocument, MultiDatabaseMixin):
     msg_mode = mongoengine.StringField(verbose_name="消息类型")
     msg_time = mongoengine.DateTimeField(verbose_name="消息时间")
 
+    content = mongoengine.StringField(
+        verbose_name="消息预览", help_text="消息预览，如果需要查看全部消息请跳转"
+    )
     illegal_list = mongoengine.ListField(
-        EmbeddedDocumentField(IllegalMeta), verbose_name="违法列表"
+        EmbeddedDocumentField(IllegalMeta), verbose_name="违规列表"
+    )
+
+    illegal_with_review = mongoengine.BooleanField(
+        verbose_name="复核是否违规", default=None, help_text="复核之后是否为真的违规"
     )
 
     create_time = mongoengine.DateTimeField(
@@ -138,9 +145,64 @@ class MessageCheckResult(mongoengine.DynamicDocument, MultiDatabaseMixin):
 
     meta = {
         "collection": "message_check_result",
-        "indexes": ["#msg_id", "#msg_mode", "msg_time"],
+        "indexes": ["#msg_id", "#msg_mode", "msg_time", "illegal_with_review"],
         "abstract": True,
     }
 
     def __str__(self):
         return f"{self.msg_id}-{self.msg_mode}-{self.illegal_list}"
+
+
+class MonitorMessageType(StrChoicesMixin):
+    PERSONAL = "PERSONAL"
+    GROUP = "GROUP"
+
+
+class MonitorExpireType(StrChoicesMixin):
+    H_24 = "H_24"
+    H_48 = "H_48"
+
+
+class ReplyMonitorResult(mongoengine.DynamicDocument, MultiDatabaseMixin):
+    external_user_id = mongoengine.StringField(verbose_name="对应external_user_id")
+    user_id = mongoengine.StringField(verbose_name="对应user_id")
+
+    group_id = mongoengine.StringField(verbose_name="群ID")
+    owner_id = mongoengine.StringField(verbose_name="群主ID")
+
+    msg_id = mongoengine.StringField(verbose_name="消息ID")
+
+    msg_type = mongoengine.StringField(
+        verbose_name="消息类型，群消息OR个人消息", choices=MonitorMessageType.choices()
+    )
+    expire_type = mongoengine.StringField(
+        verbose_name="过期类型", choices=MonitorExpireType.choices()
+    )
+
+    create_time = mongoengine.DateTimeField(
+        verbose_name="创建时间", default=datetime.datetime.now
+    )
+    meta = {
+        "collection": "reply_monitor_result",
+        "indexes": [
+            "#external_user_id",
+            "#user_id",
+            "#group_id",
+            "#owner_id",
+        ],
+        "abstract": True,
+    }
+
+
+class ReplyMonitorSkipText(mongoengine.DynamicDocument, MultiDatabaseMixin):
+    text = mongoengine.StringField(verbose_name="文本", max_length=200, unique=True)
+    is_delete = mongoengine.BooleanField(verbose_name="是否删除", default=False)
+    create_time = mongoengine.DateTimeField(
+        verbose_name="创建时间", default=datetime.datetime.now
+    )
+
+    meta = {
+        "collection": "reply_monitor_skip_text",
+        "indexes": ["text", "create_time"],
+        "abstract": True,
+    }
