@@ -62,6 +62,7 @@ class WecomExternalUser(DynamicDocument, MultiDatabaseMixin):
         verbose_name="外部联系人的自定义展示信息",
         help_text="外部联系人的自定义展示信息，可以有多个字段和多种类型，包括文本，网页和小程序，仅当联系人类型是企业微信用户时有此字段",
     )
+    insnail_customer_code = StringField(verbose_name="客户编码", help_text="对应蜗牛后台的客户编码")
 
     is_delete = BooleanField(
         verbose_name="是否被删除", help_text="是否被删除，采取软删除", default=False
@@ -78,6 +79,7 @@ class WecomExternalUser(DynamicDocument, MultiDatabaseMixin):
             "#unionid",
             "#gender",
             "#status",
+            "#insnail_customer_code",
             "is_delete",
         ],
         "abstract": True,
