@@ -77,3 +77,19 @@ class WecomMessageActionChoices(StrChoicesMixin):
     send = "发送"
     recall = "撤回"
     switch = "切换企业日志"
+
+
+class MessageModeChoices(StrChoicesMixin):
+    PERSONAL_MESSAGE = "wecom_personal_message"
+    GROUP_MESSAGE = "wecom_group_message"
+    MEETING_VOICE = "wecom_meeting_voice"
+    CALL_CENTER = "call_center"
+
+
+class IllegalMeta(mongoengine.EmbeddedDocument):
+    illegal_type = mongoengine.StringField(verbose_name="违规类型")
+    illegal_level = mongoengine.IntField(verbose_name="违规等级")
+    illegal_words = mongoengine.ListField(mongoengine.StringField(), verbose_name="违规词")
+
+    def __str__(self):
+        return f"{self.illegal_type}-{self.illegal_type}-{self.illegal_words}"
