@@ -43,6 +43,9 @@ class WecomUserBehavior(mongoengine.DynamicDocument, MultiDatabaseMixin):
     negative_feedback_cnt = mongoengine.IntField(
         verbose_name="删除及拉黑成员的客户数", help_text="删除/拉黑成员的客户数，即将成员删除或加入黑名单的客户数。", default=0
     )
+    friend_cnt = mongoengine.IntField(
+        verbose_name="客户总数", help_text="客户总数，好友人数", default=0
+    )
 
     # 群
 
