@@ -1,7 +1,10 @@
 import mongoengine
 
 from insnail_ai_tools.mongodb.mixin import MultiDatabaseMixin
-from insnail_ai_tools.mongodb.model.wecom.meta import WecomMessageActionChoices
+from insnail_ai_tools.mongodb.model.wecom.meta import (
+    IllegalMeta,
+    WecomMessageActionChoices,
+)
 
 
 class WecomGroupMessage(mongoengine.DynamicDocument, MultiDatabaseMixin):
@@ -42,12 +45,25 @@ class WecomGroupMessage(mongoengine.DynamicDocument, MultiDatabaseMixin):
     msg_time = mongoengine.DateTimeField(verbose_name="发送时间")
     create_time = mongoengine.DateTimeField(verbose_name="创建时间")
 
+    # 质检
+    is_legal = mongoengine.BooleanField(verbose_name="是否合规", default=None)
+    illegal_list = mongoengine.ListField(
+        mongoengine.EmbeddedDocumentField(IllegalMeta), verbose_name="违规列表"
+    )
+
+    illegal_with_review = mongoengine.BooleanField(
+        verbose_name="复核是否违规", default=None, help_text="复核之后是否为真的违规"
+    )
     meta = {
         "collection": "wecom_group_message",
         "indexes": [
-            "msg_time",
             "#room_id",
             "#from_user_id",
+            "#msg_type",
+            "#action",
+            "msg_time",
+            "is_legal",
+            "illegal_with_review",
         ],
         "abstract": True,
     }
