@@ -4,6 +4,7 @@ from typing import List
 import mongoengine
 
 from insnail_ai_tools.mongodb.mixin import MultiDatabaseMixin
+from insnail_ai_tools.mongodb.model.wecom.meta import IllegalMeta
 
 ASR_RESULT_PARSE_REGEX = re.compile(
     r"\[([0-9]+:[0-9.]+),([0-9]+:[0-9.]+),(\d+)\]  (.*)"
@@ -88,15 +89,28 @@ class WecomMeetingVoice(mongoengine.DynamicDocument, MultiDatabaseMixin):
         WecomMeetingVoiceMeta, verbose_name="所有对话记录"
     )
 
+    # 质检
+    is_legal = mongoengine.BooleanField(verbose_name="是否合规", default=None)
+    illegal_list = mongoengine.ListField(
+        mongoengine.EmbeddedDocumentField(IllegalMeta), verbose_name="违规列表"
+    )
+
+    illegal_with_review = mongoengine.BooleanField(
+        verbose_name="复核是否违规", default=None, help_text="复核之后是否为真的违规"
+    )
+
     meta = {
         "collection": "wecom_meeting_voice",
         "indexes": [
-            "#msg_id",
             "#user_id",
             "#external_user_id",
             "#union_id",
-            "call_type",
+            "talk_time",
+            "#call_type",
             "start_time",
+            "asr_status",
+            "is_legal",
+            "illegal_with_review",
         ],
         "abstract": True,
     }
