@@ -292,3 +292,15 @@ class WeChatExternalContactChild(WeChatExternalContact):
             conclusions=conclusions,
         )
         return self._post("externalcontact/add_contact_way", data=data)
+
+    def convert_to_openid(self, external_userid: str):
+        """
+        external_user_id 转成 openid
+
+        https://work.weixin.qq.com/api/doc/90000/90135/92323
+
+        :param external_userid: 外部联系人openid转换
+        :return: 返回的 JSON 数据包
+        """
+        data = optionaldict(external_userid=external_userid)
+        return self._post("externalcontact/convert_to_openid", data=data)
